"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isRDSModel = exports.isDynamoDBModel = exports.getModelDatasourceType = exports.getParameterStoreSecretPath = void 0;
const path_1 = __importDefault(require("path"));
const lodash_1 = __importDefault(require("lodash"));
const types_1 = require("../types");
const _1 = require(".");
const getParameterNameForDBSecret = (secret, secretsKey) => {
    return `${secretsKey}_${secret}`;
};
const getParameterStoreSecretPath = (secret, secretsKey, apiName, environmentName, appId) => {
    if (lodash_1.default.isEmpty(appId)) {
        throw new Error('Unable to read the App ID');
    }
    const categoryName = _1.APICategory;
    const paramName = getParameterNameForDBSecret(secret, secretsKey);
    if (!environmentName) {
        throw new Error('Unable to create RDS secret path, environment not found/defined');
    }
    return path_1.default.posix.join('/amplify', appId, environmentName, `AMPLIFY_${categoryName}${apiName}${paramName}`);
};
exports.getParameterStoreSecretPath = getParameterStoreSecretPath;
const getModelDatasourceType = (ctx, typename) => {
    const config = ctx.modelToDatasourceMap.get(typename);
    return (config === null || config === void 0 ? void 0 : config.dbType) || types_1.DDB_DB_TYPE;
};
exports.getModelDatasourceType = getModelDatasourceType;
const isDynamoDBModel = (ctx, typename) => {
    return (0, exports.getModelDatasourceType)(ctx, typename) === types_1.DDB_DB_TYPE;
};
exports.isDynamoDBModel = isDynamoDBModel;
const isRDSModel = (ctx, typename) => {
    return (0, exports.getModelDatasourceType)(ctx, typename) === types_1.MYSQL_DB_TYPE;
};
exports.isRDSModel = isRDSModel;
//# sourceMappingURL=rds-util.js.map